==> tdenetwork-trinity_14.1.1.orig.tar.xz: tdenetwork-trinity-14.1.1/kopete/protocols/oscar/oscarmyselfcontact.h <==
/*
  oscarmyselfcontact.h  -  Oscar Protocol Plugin Myself Contact

  Copyright (c) 2004 by Richard Smith               <kde@metafoo.co.uk>
  Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>

  *************************************************************************
  *                                                                       *
  * This program is free software; you can redistribute it and/or modify  *
  * it under the terms of the GNU General Public License as published by  *
  * the Free Software Foundation; either version 2 of the License, or     *
  * (at your option) any later version.                                   *
  *                                                                       *
  *************************************************************************
  */

#ifndef OSCARMYSELFCONTACT_H
#define OSCARMYSELFCONTACT_H

#include "kopetecontact.h"
#include "userdetails.h"

namespace Kopete
{
class ChatSession;
class OnlineStatus;
}

class OscarAccount;
class TQTimer;
class TDEToggleAction;

/**
 * myself() contact for oscar protocol
 * @author Richard Smith
 */
class KDE_EXPORT OscarMyselfContact : public Kopete::Contact
{
TQ_OBJECT
  

public:
	OscarMyselfContact( OscarAccount* account );
	virtual ~OscarMyselfContact();
	
	virtual bool isReachable();
	virtual Kopete::ChatSession *manager( CanCreateFlags canCreate );
	
	UserDetails details();
	
public slots:
	/** our user info has been updated */
	virtual void userInfoUpdated() = 0;
	
	/** I'm sorry Dave, I can't let you do that... */
	virtual void deleteContact();
};

#endif

==> tdenetwork-trinity-14.1.5.tar.xz: tdenetwork-trinity-14.1.5/kopete/protocols/oscar/oscarmyselfcontact.h <==
/*
  oscarmyselfcontact.h  -  Oscar Protocol Plugin Myself Contact

  Copyright (c) 2004 by Richard Smith               <kde@metafoo.co.uk>
  Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>

  *************************************************************************
  *                                                                       *
  * This program is free software; you can redistribute it and/or modify  *
  * it under the terms of the GNU General Public License as published by  *
  * the Free Software Foundation; either version 2 of the License, or     *
  * (at your option) any later version.                                   *
  *                                                                       *
  *************************************************************************
  */

#ifndef OSCARMYSELFCONTACT_H
#define OSCARMYSELFCONTACT_H

#include "kopetecontact.h"
#include "userdetails.h"

namespace Kopete
{
class ChatSession;
class OnlineStatus;
}

class OscarAccount;
class TQTimer;
class TDEToggleAction;

/**
 * myself() contact for oscar protocol
 * @author Richard Smith
 */
class TDE_EXPORT OscarMyselfContact : public Kopete::Contact
{
TQ_OBJECT
  

public:
	OscarMyselfContact( OscarAccount* account );
	virtual ~OscarMyselfContact();
	
	virtual bool isReachable();
	virtual Kopete::ChatSession *manager( CanCreateFlags canCreate );
	
	UserDetails details();
	
public slots:
	/** our user info has been updated */
	virtual void userInfoUpdated() = 0;
	
	/** I'm sorry Dave, I can't let you do that... */
	virtual void deleteContact();
};

#endif
